class FireBomb {
	constructor(game, x, y, r){
		this.game = game;
		
		// Rendering
		this.texture = game.textures.projectiles;
		this.map = game.atlas.projectiles.fireBomb;
		
		// Scale
		this.scale = 1;
		this.width = this.scale * 5;
		this.height = this.scale * 5;
		
		// Physics
		this.x = x;
		this.y = y;
		this.r = r;
		this.vx = 0;
		this.vy = 0;
		this.vr = (Math.random() * 2 - 1);
		
		this.collision = {
			with: [ Alien ],
			width: 0,
			height: 0,
			radius: 0,
			offsetX: 0,
			offsetY: 0,
			hitRadius: 0,
			isDud: true,
			
			piercing: true,
			
			reaction: burnReaction
		};
		
		// Fire Bomb
		this.maxLife = 1;
		this.life = this.maxLife;
		this.isAlive = true;
	}
	
	
	update(delta){
		// var speed = this.speed * this.life / this.maxLife;
		
		// this.x += speed * Math.sin(this.r/180*Math.PI);
		// this.y += speed * -Math.cos(this.r/180*Math.PI);
		this.r += this.vr;
		
		if(this.life - delta <= 0){
			this.game.playTrack("explode");
			this.game.shake(0.2, 0.5);
			
			for(var i=0; i<4; i++){
				var particle = new Explosion(this.game, this.game.textures.projectiles, this.game.atlas.particles.explosion.orange, this.x + (Math.random() * 2 - 1) * 10, this.y + (Math.random() * 2 - 1) * 10, 360 * Math.random(), this.vx, this.vy, this.vr);
				particle.maxLife = Math.random() * 0.3 + 0.5;
				particle.life = particle.maxLife;
				this.game.scene.addParticle(particle)
			}
			
			for(var i=0; i<32; i++){
				var projectile = new Flamethrower(this.game, this.x, this.y, i / 32 * 360);
				projectile.maxLife = 0.6;
				projectile.life = projectile.maxLife - 0.01;
				projectile.collision.hitRadius = 5;
				projectile.collision.piercing = false;
				projectile.collision.isDud = false;
				this.game.scene.addObject(projectile)
			}
			
			/*this.width = this.collision.width;
			this.height = this.collision.height;
			this.collision.isDud = false;*/
			
			doCollision(this);
		}
		
		return this.life -= delta;;
	}
	
	
	draw(context, textures, atlas){
		var texture = this.texture,
			map = this.map;
		
		context.save();
		context.translate(this.x, this.y);
		context.rotate(this.r/180*Math.PI);
		
		context.globalAlpha = (1 - this.life / this.maxLife) * 10;
		context.drawImage(texture, map[0], map[1], map[2], map[3], -map[2]/2 * this.scale, -map[3]/2 * this.scale, map[2] * this.scale, map[3] * this.scale);
		
		context.restore();
	}
}
